Run the performance test based on a single commit using shinytest2
run_shinytest2_ptest(
commit,
project_path,
app_dir,
shinytest2_dir,
tests_pattern,
use_renv,
renv_prompt,
n_rep,
debug
)Return a data.frame with the collected performance time
A commit hash code or a branch's name
The path to the project
The path to the application root
The directory with tests recorded by shinytest2
shinytest2 files pattern. E.g. 'performance'. If it is NULL, all the content will be used
In case it is set as TRUE, package will try to apply renv::restore() in all branches. Otherwise, the current loaded list of packages will be used in all branches.
Prompt the user before taking any action?
Number of replications desired
Logical. TRUE to display all the system messages on runtime